Module store

Module store 

Structs

NativeGitStorage
Git-native session storage using gix.
PruneStats
Result of a git-native retention prune run.
SessionSummaryLedgerRecord
Session semantic summary payload persisted in hidden refs.
StoredSessionRecord
Result of storing a session at an explicit ref.
StoredSummaryRecord
Result of storing a semantic summary at an explicit ref.

Functions

store_blob_at_ref
Store arbitrary blob content under a specific ref/path without touching the working tree.