Structs
- Native
GitStorage - Git-native session storage using gix.
- Prune
Stats - Result of a git-native retention prune run.
- Session
Summary Ledger Record - Session semantic summary payload persisted in hidden refs.
- Stored
Session Record - Result of storing a session at an explicit ref.
- Stored
Summary Record - Result of storing a semantic summary at an explicit ref.
Functions
- store_
blob_ at_ ref - Store arbitrary blob content under a specific ref/path without touching the working tree.